require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_wsmanserviceconfig',
  dscmeta_resource_friendly_name: 'WSManServiceConfig',
  dscmeta_resource_name: 'DSR_WSManServiceConfig',
  dscmeta_module_name: 'WSManDsc',
  dscmeta_module_version: '2.1.0.78',
  docs: 'The DSC WSManServiceConfig resource type.
         Automatically generated from version 2.1.0.78',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_authkerberos: {
      type: 'Optional[Boolean]',
      desc: 'Allows the WinRM service to use Kerberos authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_authnegotiate: {
      type: 'Optional[Boolean]',
      desc: 'Allows the WinRM service to use Negotiate authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_authcbthardeninglevel: {
      type: "Optional[Enum['Strict', 'Relaxed', 'None']]",
      desc: 'Allows the client computer to request unencrypted traffic.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxconcurrentoperationsperuser: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of concurrent operations that any user can remotely open on the same system.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_authcertificate: {
      type: 'Optional[Boolean]',
      desc: 'Allows the WinRM service to use client certificate-based authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rootsddl: {
      type: 'Optional[String]',
      desc: 'Specifies the security descriptor that controls remote access to the listener.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enumerationtimeoutms: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the idle time-out in milliseconds between Pull messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_authcredssp: {
      type: 'Optional[Boolean]',
      desc: 'Allows the WinRM service to use Credential Security Support Provider (CredSSP) authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxconnections: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of active requests that the service can process simultaneously.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowunencrypted: {
      type: 'Optional[Boolean]',
      desc: 'Allows the client computer to request unencrypted traffic.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablecompatibilityhttplistener: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the compatibility HTTP listener is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_authbasic: {
      type: 'Optional[Boolean]',
      desc: 'Allows the WinRM service to use Basic authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablecompatibilityhttpslistener: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the compatibility HTTPS listener is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxpacketretrievaltimeseconds: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum length of time, in seconds, the WinRM service takes to retrieve a packet.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
